/*
** Module   : AttributeMethodDescriptor.java
** Abstract : small container class used to store conversion mapping info for 4GL attributes and
**            4GL methods
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description--------------------------------
** 001 GES 20141012 First version.
*/

package com.goldencode.p2j.convert;

/**
 * This is a small container class used to store conversion mapping info for 4GL attributes and
 * 4GL methods.
 */
public class AttributeMethodDescriptor
{
   /** The type of the resource used for unwrapping handles. */
   public String wrapper = null;
   
   /** Java method used as a getter for attributes and the only thing called for 4GL methods. */
   public String getter = null;
   
   /** Java method used as a setter for attribute assignment. */
   public String setter = null;
   
   /** Flag to denote if the getter/setters are static or instance methods. */
   public boolean instance = true;
   
   /**
    * Obtain the type of the resource used for unwrapping handles.
    *
    * @return   The resource type.
    */
   public String getWrapper()
   {
      return wrapper;
   }
   
   /**
    * Assign the type of the resource used for unwrapping handles.
    *
    * @param   wrapper
    *          The resource type.
    */
   public void setWrapper(String wrapper)
   {
      this.wrapper = wrapper; 
   }
   
   /**
    * Obtain the Java method used as a getter for attributes and the only thing called for 4GL
    * methods.
    *
    * @return   The method name.
    */
   public String getGetter()
   {
      return getter; 
   }
   
   /**
    * Assign the Java method used as a getter for attributes and the only thing called for 4GL
    * methods.
    *
    * @param   getter
    *          The method name.
    */
   public void setGetter(String getter)
   {
      this.getter = getter; 
   }
   
   /**
    * Obtain the Java method used as a setter for attributes.
    *
    * @return   The method name.
    */
   public String getSetter()
   {
      return setter;
   }
   
   /**
    * Assign the Java method used as a setter for attributes.
    *
    * @param   setter
    *          The method name.
    */
   public void setSetter(String setter)
   {
      this.setter = setter;
   }

   /**
    * Obtain the flag that denotes if the getter/setters are static or instance methods.
    *
    * @return   <code>true</code> if this is an instance method.
    */
   public boolean getInstance()
   {
      return instance;
   }
   
   /**
    * Assign the flag that denotes if the getter/setters are static or instance methods.
    *
    * @param   instance
    *          <code>true</code> if this is an instance method.
    */
   public void setInstance(boolean instance)
   {
      this.instance = instance;
   }
}
